Struct GtkPrimarySelectionOffer
pub struct GtkPrimarySelectionOffer { /* private fields */ }wayland and Linux only.Expand description
offer to transfer primary selection contents
A wp_primary_selection_offer represents an offer to transfer the contents of the primary selection clipboard to the client. Similar to wl_data_offer, the offer also describes the mime types that the source will transferthat the data can be converted to and provides the mechanisms for transferring the data directly to the client.
See also the Event enum for this interface.
Implementations
impl GtkPrimarySelectionOffer
impl GtkPrimarySelectionOffer
pub fn receive(&self, mime_type: String, fd: BorrowedFd<'_>)
pub fn receive(&self, mime_type: String, fd: BorrowedFd<'_>)
request that the data is transferred
To transfer the contents of the primary selection clipboard, the client issues this request and indicates the mime type that it wants to receive. The transfer happens through the passed file descriptor (typically created with the pipe system call). The source client writes the data in the mime type representation requested and then closes the file descriptor.
The receiving client reads from the read end of the pipe until EOF and closes its end, at which point the transfer is complete.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the primary selection offer
Destroy the primary selection offer.